@@ -42,6 +42,7 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "django.contrib.sites",
         "django_crypto_fields.apps.AppConfig",
         "django_revision.apps.AppConfig",
+        "edc_appointment.apps.AppConfig",
         "edc_action_item.apps.AppConfig",
         "edc_adverse_event.apps.AppConfig",
         "adverse_event_app.apps.AppConfig",
@@ -53,6 +54,7 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "edc_device.apps.AppConfig",
         "edc_identifier.apps.AppConfig",
         "edc_lab.apps.AppConfig",
+        "edc_listboard.apps.AppConfig",
         "edc_locator.apps.AppConfig",
         "edc_navbar.apps.AppConfig",
         "edc_model_admin.apps.AppConfig",
@@ -69,9 +71,8 @@ DEFAULT_SETTINGS = DefaultTestSettings(
         "edc_subject_dashboard.apps.AppConfig",
         "edc_timepoint.apps.AppConfig",
         "edc_visit_schedule.apps.AppConfig",
-        "edc_data_manager.apps.EdcVisitTrackingAppConfig",
+        "edc_visit_tracking.apps.AppConfig",
         "edc_data_manager.apps.EdcFacilityAppConfig",
-        "edc_data_manager.apps.EdcAppointmentAppConfig",
         "edc_data_manager.apps.EdcMetadataAppConfig",
         "edc_data_manager.apps.AppConfig",
         "data_manager_app.apps.AppConfig",
